/*
 * $Id: RADIUSauth.h,v 1.6.2.1 2005/03/13 17:09:38 hweiss Exp $
 *
 * RADIUS Plugin for pGina
 * Copyright (c) 2004, 2005 Holger Weiss <holger@ZEDAT.FU-Berlin.DE>
 * Copyright (c) 2005 Kostas Kalevras <kkalev@noc.ntua.gr>
 *
 * ---------------------------------------------------------------------------
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc., 59
 * Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * ---------------------------------------------------------------------------
 *
 * This code is based on pam_radius_auth, copyright (c) 2003 Alan DeKok.
 */

#ifndef RADIUSauth_H
#define RADIUSauth_H

#pragma once

#ifndef __AFXWIN_H__
#error include 'stdafx.h' before including this file for PCH
#endif				/* __AFXWIN_H__ */

#include <sys/stat.h>
#include <sys/types.h>
#include <winsock2.h>
#include <ctype.h>
#include <errno.h>
#include <fcntl.h>
#include <process.h>
#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include "RADIUSplugin.h"

/* RADIUSauth return values */
#define RADIUS_SUCCESS			0
#define RADIUS_FAILURE			1
#define RADIUS_AUTH_ERR			2
#define RADIUS_AUTHINFO_UNAVAIL		3
#define RADIUS_SESSION_ERR		4
#define RADIUS_PERM_DENIED		5
#define RADIUS_AUTHTOK_ERR		6

#define	RADIUS_PACKET_LEN	4096

/* Other defines */
#ifndef BUFFER_SIZE
#define BUFFER_SIZE	1024
#endif				/* BUFFER_SIZE */
#ifndef FALSE
#define FALSE		0
#undef TRUE
#define TRUE		!FALSE
#endif				/* FALSE */

/* Macros */
#define _radius_forget(X)	if (X) {memset(X, 0, strlen(X));free(X);X = NULL;}
#define _radius_drop(X)		if (X) {free(X);X = NULL;}

/* ---------------------------------------------------------------------------
 * Additional RADIUS definitions
 */

typedef struct attribute_t
{
	unsigned char   attribute;
	unsigned char   length;
	unsigned char   data[1];
}
attribute_t;

typedef struct vendor_attribute {
	unsigned int	vendor;
	unsigned char	attribute;
	unsigned char	length;
	unsigned char	data[1];
}
vendor_attr_t;


typedef struct radius_server_t
{
	struct radius_server_t *next;
	struct sockaddr_in ip;
	u_short         radius_port;
	u_short         radacct_port;
	char           *hostname;
	char           *secret;
	int             timeout;
}
radius_server_t;

typedef struct radius_conf_t
{
	radius_server_t *server;
	int             retries;
	int             accounting_bug;
	unsigned        sockfd;
	int             debug;
}
radius_conf_t;

typedef struct request_t
{
	radius_server_t *server;
	char *Class;
	char s_id[12];
	time_t login_time;
}
request_t;

/* ---------------------------------------------------------------------------
 * Exported functions
 */

int             authenticate(const char *user, char *password, pGinaInfo *settingsInfo);
int             accounting(const char *user, int status);
int             chpasswd(const char *user, char *password, char *new_password);

#endif				/* RADIUSauth_H */
