//
// $Id: RADIUSconfig.cpp,v 1.7 2005/03/03 19:31:49 hweiss Exp $
//
// RADIUS Plugin for pGina
// Copyright (c) 2004, 2005 Holger Weiss <holger@ZEDAT.FU-Berlin.DE>
// Copyright (c) 2005 Kostas Kalevras <kkalev@noc.ntua.gr>
//
// ---------------------------------------------------------------------------
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the Free
// Software Foundation; either version 2 of the License, or (at your option)
// any later version.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
// more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc., 59
// Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// ---------------------------------------------------------------------------
//

#include "stdafx.h"
#include "RADIUSconfig.h"
#include "RADIUShelpers.h"

// ---------------------------------------------------------------------------
// CRADIUSconfig dialog

IMPLEMENT_DYNAMIC(CRADIUSconfig, CDialog)
CRADIUSconfig::CRADIUSconfig(CWnd* pParent /*=NULL*/)
		: CDialog(CRADIUSconfig::IDD, pParent)
		, m_server1(_T(""))
		, m_server2(_T(""))
		, m_server3(_T(""))
		, m_secret1(_T(""))
		, m_secret2(_T(""))
		, m_secret3(_T(""))
		, m_anonymous_filter(_T(""))
		, m_nas(_T(""))
		, m_port1(0)
		, m_port2(0)
		, m_port3(0)
		, m_local_port(0)
		, m_service_type(1)
		, m_timeout(3)
		, m_accounting(FALSE)
		, m_secure_key(FALSE)
		, m_livingston(FALSE)
		, m_only_local(FALSE)
		, m_required(FALSE)
		, m_admin(FALSE)
		, m_debug(FALSE)
		, m_pw_change(FALSE)
		, m_userlogon(FALSE)
		, m_anonymous(FALSE)
{
	CString server1_from_reg(regReadString("server1"));
	CString server2_from_reg(regReadString("server2"));
	CString server3_from_reg(regReadString("server3"));
	CString secret1_from_reg(regReadString("secret1"));
	CString secret2_from_reg(regReadString("secret2"));
	CString secret3_from_reg(regReadString("secret3"));
	CString anonymous_filter_from_reg(regReadString("anonymous_filter"));
	CString nas_from_reg(regReadString("nas"));
	unsigned long port1_from_reg = regReadUlong("port1");
	unsigned long port2_from_reg = regReadUlong("port2");
	unsigned long port3_from_reg = regReadUlong("port3");
	unsigned long local_port_from_reg = regReadUlong("local_port");
	unsigned long service_type_from_reg = regReadUlong("service_type");
	unsigned long timeout_from_reg = regReadUlong("timeout");

	if (server1_from_reg.GetLength())
		m_server1 = server1_from_reg;
	else
		m_server1 = SERVER1_TXT;
	if (server2_from_reg.GetLength())
		m_server2 = server2_from_reg;
	else
		m_server2 = SERVER2_TXT;
	if (server3_from_reg.GetLength())
		m_server3 = server3_from_reg;
	else
		m_server3 = SERVER3_TXT;
	if (secret1_from_reg.GetLength())
		m_secret1 = secret1_from_reg;
	else
		m_secret1 = SECRET1_TXT;
	if (secret2_from_reg.GetLength())
		m_secret2 = secret2_from_reg;
	else
		m_secret2 = SECRET2_TXT;
	if (secret3_from_reg.GetLength())
		m_secret3 = secret3_from_reg;
	else
		m_secret3 = SECRET3_TXT;
	if (anonymous_filter_from_reg.GetLength())
		m_anonymous_filter = anonymous_filter_from_reg;
	else
		m_anonymous_filter = ANONYMOUS_FILTER_TXT;
	if (nas_from_reg.GetLength())
		m_nas = nas_from_reg;
	else
		m_nas = NAS_TXT;

	m_port1 = (port1_from_reg && (port1_from_reg <= 64000)) ? port1_from_reg : 0;
	m_port2 = (port2_from_reg && (port2_from_reg <= 64000)) ? port2_from_reg : 0;
	m_port3 = (port3_from_reg && (port3_from_reg <= 64000)) ? port3_from_reg : 0;
	m_local_port = local_port_from_reg ? local_port_from_reg : 0;
	m_service_type = service_type_from_reg ? service_type_from_reg : DEFAULT_SERVICE_TYPE;
	m_timeout = timeout_from_reg ? timeout_from_reg : DEFAULT_TIMEOUT;

	m_accounting = regReadBool("accounting");
	m_secure_key = regReadBool("secure_key");
	m_livingston = regReadBool("livingston");
	m_only_local = regReadBool("only_local");
	m_required = regReadBool("required");
	m_admin = regReadBool("admin");
	m_debug = regReadBool("debug");
	m_pw_change = regReadBool("pw_change");
	m_anonymous = regReadBool("anonymous");
	m_userlogon = regReadBool("userlogon");
}

CRADIUSconfig::~CRADIUSconfig()
{}

// Data exchange

void CRADIUSconfig::DoDataExchange(CDataExchange* pDX)
{
	DDX_Text(pDX, IDC_SERVER1, m_server1);
	DDX_Text(pDX, IDC_SERVER2, m_server2);
	DDX_Text(pDX, IDC_SERVER3, m_server3);
	DDX_Text(pDX, IDC_PORT1, m_port1);
	DDX_Text(pDX, IDC_PORT2, m_port2);
	DDX_Text(pDX, IDC_PORT3, m_port3);
	DDX_Text(pDX, IDC_SECRET1, m_secret1);
	DDX_Text(pDX, IDC_SECRET2, m_secret2);
	DDX_Text(pDX, IDC_SECRET3, m_secret3);
	DDX_Text(pDX, IDC_LOCAL_PORT, m_local_port);
	DDX_Text(pDX, IDC_LOGINTYPE, m_service_type);
	DDX_Text(pDX, IDC_TIMEOUT, m_timeout);
	DDX_Text(pDX, IDC_ANONYMOUSFILTER, m_anonymous_filter);
	DDX_Text(pDX, IDC_NAS, m_nas);

	DDX_Check(pDX, IDC_ACCOUNTING, m_accounting);
	DDX_Check(pDX, IDC_SECURE_KEY, m_secure_key);
	DDX_Check(pDX, IDC_LIVINGSTON, m_livingston);
	DDX_Check(pDX, IDC_ONLY_LOCAL, m_only_local);
	DDX_Check(pDX, IDC_REQUIRED, m_required);
	DDX_Check(pDX, IDC_ADMIN, m_admin);
	DDX_Check(pDX, IDC_DEBUG, m_debug);
	DDX_Check(pDX, IDC_CHPASSWD, m_pw_change);
	DDX_Check(pDX, IDC_ANONYMOUS, m_anonymous);
	DDX_Check(pDX, IDC_USERLOGON, m_userlogon);

	CDialog::DoDataExchange(pDX);
}

BEGIN_MESSAGE_MAP(CRADIUSconfig, CDialog)
ON_BN_CLICKED(IDOK, OnBnClickedOk)
ON_STN_CLICKED(IDC_ABOUT_TEXT, OnStnClickedAboutText)
END_MESSAGE_MAP()

// CRADIUSconfig handler

void CRADIUSconfig::OnBnClickedOk()
{
	UpdateData(TRUE);
	bool error = false;

	if (m_server1 != SERVER1_TXT)
		if (!regWriteString(convert_to_char(m_server1), "server1"))
			error = true;
	if (m_server2 != SERVER2_TXT)
		if (!regWriteString(convert_to_char(m_server2), "server2"))
			error = true;
	if (m_server3 != SERVER3_TXT)
		if (!regWriteString(convert_to_char(m_server3), "server3"))
			error = true;
	if (m_secret1 != SECRET1_TXT)
		if (!regWriteString(convert_to_char(m_secret1), "secret1"))
			error = true;
	if (m_secret2 != SECRET2_TXT)
		if (!regWriteString(convert_to_char(m_secret2), "secret2"))
			error = true;
	if (m_secret3 != SECRET3_TXT)
		if (!regWriteString(convert_to_char(m_secret3), "secret3"))
			error = true;
	if (m_anonymous_filter != ANONYMOUS_FILTER_TXT)
		if (!regWriteString(convert_to_char(m_anonymous_filter), "anonymous_filter"))
			error = true;
	if (m_nas != NAS_TXT)
		if (!regWriteString(convert_to_char(m_nas), "nas"))
			error = true;

	if ((m_port1 >= 0) && (m_port1 <= 64000))
		if (!regWriteUlong(m_port1, "port1"))
			error = true;
	if ((m_port2 >= 0) && (m_port2 <= 64000))
		if (!regWriteUlong(m_port2, "port2"))
			error = true;
	if ((m_port3 >= 0) && (m_port3 <= 64000))
		if (!regWriteUlong(m_port3, "port3"))
			error = true;
	if ((m_local_port >= 0) && (m_local_port <= 64000))
		if (!regWriteUlong(m_local_port, "local_port"))
			error = true;
	if (m_service_type >= 0)
		if (!regWriteUlong(m_service_type, "service_type"))
			error = true;
	if (m_timeout >= 0)
		if (!regWriteUlong(m_timeout, "timeout"))
			error = true;

	if (!regWriteBool(m_accounting, "accounting"))
		error = true;
	if (!regWriteBool(m_secure_key, "secure_key"))
		error = true;
	if (!regWriteBool(m_livingston, "livingston"))
		error = true;
	if (!regWriteBool(m_only_local, "only_local"))
		error = true;
	if (!regWriteBool(m_required, "required"))
		error = true;
	if (!regWriteBool(m_admin, "admin"))
		error = true;
	if (!regWriteBool(m_debug, "debug"))
		error = true;
	if (!regWriteBool(m_pw_change, "pw_change"))
		error = true;
	if (!regWriteBool(m_anonymous, "anonymous"))
		error = true;
	if (!regWriteBool(m_userlogon, "userlogon"))
		error = true;

	if (!error)
		MessageBox(TEXT("RADIUSplugin settings saved"),
		           TEXT("Settings saved"), MB_OK);
	else
		MessageBox(TEXT("Error saving configuration to Registry"),
		           TEXT("RADIUSplugin error"), MB_ICONERROR);

	if (!regSecureKey())
		MessageBox(TEXT("Can't set access control list for Registry key!"),
		           TEXT("RADIUSplugin error"), MB_ICONERROR);

	OnOK();
}

void CRADIUSconfig::OnStnClickedAboutText()
{
	// TODO: Add your control notification handler code here
}